/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __LCB_DBUS_H__
#define __LCB_DBUS_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.cbd */

#define LCB_DBUS_TYPE_CBD (lcb_dbus_cbd_get_type ())
#define LCB_DBUS_CBD(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), LCB_DBUS_TYPE_CBD, LcbDBusCbd))
#define LCB_DBUS_IS_CBD(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), LCB_DBUS_TYPE_CBD))
#define LCB_DBUS_CBD_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), LCB_DBUS_TYPE_CBD, LcbDBusCbdIface))

struct _LcbDBusCbd;
typedef struct _LcbDBusCbd LcbDBusCbd;
typedef struct _LcbDBusCbdIface LcbDBusCbdIface;

struct _LcbDBusCbdIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_open_messages) (
    LcbDBusCbd *object,
    GDBusMethodInvocation *invocation);

  gboolean  (*get_cbs_supported) (LcbDBusCbd *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LcbDBusCbd, g_object_unref)
#endif

GType lcb_dbus_cbd_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *lcb_dbus_cbd_interface_info (void);
guint lcb_dbus_cbd_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void lcb_dbus_cbd_complete_open_messages (
    LcbDBusCbd *object,
    GDBusMethodInvocation *invocation,
    GVariant *result);



/* D-Bus method calls: */
void lcb_dbus_cbd_call_open_messages (
    LcbDBusCbd *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean lcb_dbus_cbd_call_open_messages_finish (
    LcbDBusCbd *proxy,
    GVariant **out_result,
    GAsyncResult *res,
    GError **error);

gboolean lcb_dbus_cbd_call_open_messages_sync (
    LcbDBusCbd *proxy,
    GVariant **out_result,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
gboolean lcb_dbus_cbd_get_cbs_supported (LcbDBusCbd *object);
void lcb_dbus_cbd_set_cbs_supported (LcbDBusCbd *object, gboolean value);


/* ---- */

#define LCB_DBUS_TYPE_CBD_PROXY (lcb_dbus_cbd_proxy_get_type ())
#define LCB_DBUS_CBD_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), LCB_DBUS_TYPE_CBD_PROXY, LcbDBusCbdProxy))
#define LCB_DBUS_CBD_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), LCB_DBUS_TYPE_CBD_PROXY, LcbDBusCbdProxyClass))
#define LCB_DBUS_CBD_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), LCB_DBUS_TYPE_CBD_PROXY, LcbDBusCbdProxyClass))
#define LCB_DBUS_IS_CBD_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), LCB_DBUS_TYPE_CBD_PROXY))
#define LCB_DBUS_IS_CBD_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), LCB_DBUS_TYPE_CBD_PROXY))

typedef struct _LcbDBusCbdProxy LcbDBusCbdProxy;
typedef struct _LcbDBusCbdProxyClass LcbDBusCbdProxyClass;
typedef struct _LcbDBusCbdProxyPrivate LcbDBusCbdProxyPrivate;

struct _LcbDBusCbdProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  LcbDBusCbdProxyPrivate *priv;
};

struct _LcbDBusCbdProxyClass
{
  GDBusProxyClass parent_class;
};

GType lcb_dbus_cbd_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LcbDBusCbdProxy, g_object_unref)
#endif

void lcb_dbus_cbd_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
LcbDBusCbd *lcb_dbus_cbd_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
LcbDBusCbd *lcb_dbus_cbd_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void lcb_dbus_cbd_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
LcbDBusCbd *lcb_dbus_cbd_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
LcbDBusCbd *lcb_dbus_cbd_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define LCB_DBUS_TYPE_CBD_SKELETON (lcb_dbus_cbd_skeleton_get_type ())
#define LCB_DBUS_CBD_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), LCB_DBUS_TYPE_CBD_SKELETON, LcbDBusCbdSkeleton))
#define LCB_DBUS_CBD_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), LCB_DBUS_TYPE_CBD_SKELETON, LcbDBusCbdSkeletonClass))
#define LCB_DBUS_CBD_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), LCB_DBUS_TYPE_CBD_SKELETON, LcbDBusCbdSkeletonClass))
#define LCB_DBUS_IS_CBD_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), LCB_DBUS_TYPE_CBD_SKELETON))
#define LCB_DBUS_IS_CBD_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), LCB_DBUS_TYPE_CBD_SKELETON))

typedef struct _LcbDBusCbdSkeleton LcbDBusCbdSkeleton;
typedef struct _LcbDBusCbdSkeletonClass LcbDBusCbdSkeletonClass;
typedef struct _LcbDBusCbdSkeletonPrivate LcbDBusCbdSkeletonPrivate;

struct _LcbDBusCbdSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  LcbDBusCbdSkeletonPrivate *priv;
};

struct _LcbDBusCbdSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType lcb_dbus_cbd_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LcbDBusCbdSkeleton, g_object_unref)
#endif

LcbDBusCbd *lcb_dbus_cbd_skeleton_new (void);


G_END_DECLS

#endif /* __LCB_DBUS_H__ */
